{% load i18n static %}

<div class="flex items-center ml-auto">
    <div class="flex flex-row group items-center leading-none relative">
        <div class="flex gap-4">
            {% include "unfold/helpers/theme_switch.html" %}

            {% include "unfold/helpers/account_links.html" %}
        </div>
    </div>

    {% if nav_global_side %}
        {{ nav_global_side }}
    {% endif %}
</div>
