
<li class="text-gray-500 text-xs dark:text-gray-400">
    {% if link %}
        <a href="{{ link }}">{{ name }}</a> <span class="mx-2 text-gray-200 dark:text-gray-600">/</span>
    {% else %}
        {{ name }}
    {% endif %}
</li>
