{% extends "admin/change_form.html" %}
{% load i18n %}

{% block form_top %}
    <p class="bg-blue-50 border-blue-200 mb-8 p-3 rounded-md text-blue-500 text-sm dark:bg-blue-500/20 dark:border-blue-500/10">
        {% if not is_popup %}
            {% translate 'First, enter a username and password. Then, you’ll be able to edit more user options.' %}
        {% else %}
            {% translate "Enter a username and password." %}x
        {% endif %}
    <p>
{% endblock %}
